from cryptography.fernet import Fernet
from base64 import urlsafe_b64encode, urlsafe_b64decode

# Mot de passe par défaut
DEFAULT_PASSWORD = "mon_password_secret"

def generate_key(password):
    return Fernet.generate_key()

def encrypt(text, key):
    fernet = Fernet(key)
    encrypted_text = fernet.encrypt(text.encode())
    return urlsafe_b64encode(encrypted_text)

def decrypt(encrypted_text, key):
     fernet = Fernet(key)
     decrypted_text = fernet.decrypt(urlsafe_b64decode(encrypted_text)).decode('utf-8')
     return decrypted_text



from cryptography.fernet import Fernet
from encrypt import encrypt

# Mot de passe par défaut
DEFAULT_PASSWORD = "mon_password_secret"


def main():
    key = Fernet.generate_key()

    # Vérification du mot de passe
    entered_password = input("Entrez le mot de passe : ")
    if entered_password != DEFAULT_PASSWORD:
        print("Mot de passe incorrect. L'encryption et le déchiffrement ne sont pas autorisés.")
        return

    # Le mot de passe est correct, poursuivre avec l'encryption/déchiffrement
    text_to_encrypt = input("Entrez le texte à chiffrer : ")

    encrypted_text = encrypt(text_to_encrypt, key)
    print(f"Encrypted text: {encrypted_text}")

    decrypted_text = decrypt(encrypted_text, key)
    print(f"Decrypted text: {decrypted_text}")


if __name__ == "__main__":
    main()



import setuptools
setuptools.setup(
 name='Ceasar_encryptage',
 version='1.0.1',
 author="Cyberwolf",
 author_email="ralphsaintil0@gmail.com",
 description="c'est un algoritme de cryptage classique",
 packages=setuptools.find_packages(),
 install_requires=[
     'cryptography'
    ],
 classifiers=[
 "Programming Language :: Python :: 3",
 "License :: OSI Approved :: MIT License",
 "Operating System :: OS Independent",
 ],
)